FaceGateResult class
Result of evaluating face proximity and aspect ratio constraints.
Constructors
- FaceGateResult({required bool isValid, required LivenessStatus status, required double faceAreaRatio, required double aspectRatio})
-
const
- FaceGateResult.valid({required double faceAreaRatio, required double aspectRatio})
-
Factory constructor for a valid face gate evaluation.
factory
Properties
- aspectRatio → double
-
Calculated aspect ratio ($\text{width} / \text{height}$) of the face bounding box.
final
- faceAreaRatio → double
-
Calculated ratio of face area relative to overall camera frame area ($0.0 \dots 1.0$).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
Whether the face bounding box passes proximity and aspect ratio checks.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → LivenessStatus
-
Specific failure status if invalid (
tooFar,tooClose, orinvalidAspectRatio).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited