FaceProximityGate class
Evaluates face area coverage and bounding box aspect ratios to reject presentation attacks using small printed photos or extreme lens close-ups.
Constructors
- FaceProximityGate({double minFaceAreaRatio = 0.05, double maxFaceAreaRatio = 0.85, double minAspectRatio = 0.50, double maxAspectRatio = 1.25})
-
Creates a FaceProximityGate with customizable thresholds.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAspectRatio → double
-
Maximum valid face bounding box aspect ratio (width / height, default: 1.25).
final
- maxFaceAreaRatio → double
-
Maximum allowed face area ratio relative to frame size (default: 85% / 0.85).
final
- minAspectRatio → double
-
Minimum valid face bounding box aspect ratio (width / height, default: 0.50).
final
- minFaceAreaRatio → double
-
Minimum allowed face area ratio relative to frame size (default: 5% / 0.05).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluate(
{required FaceBoundingBox boundingBox, required int frameWidth, required int frameHeight, int rotation = 0}) → FaceGateResult -
Evaluates a
boundingBoxagainst camera frame dimensions (frameWidth,frameHeight). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited